ModifiersState

Struct ModifiersState 

pub struct ModifiersState(/* private fields */);
Represents the current state of the keyboard modifiers

Each flag represents a modifier and is set if this modifier is active.

Implementations

Source

impl ModifiersState

pub const SHIFT: Self

The “shift” key.

pub const CONTROL: Self

The “control” key.

pub const ALT: Self

The “alt” key.

pub const SUPER: Self

This is the “windows” key on PC and “command” key on Mac.

Source

impl ModifiersState

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

Examples found in repository?
examples/window.rs (line 1019)
1010fn modifiers_to_string(mods: ModifiersState) -> String {
1011    let mut mods_line = String::new();
1012    // Always add + since it's printed as a part of the bindings.
1013    for (modifier, desc) in [
1014        (ModifiersState::SUPER, "Super+"),
1015        (ModifiersState::ALT, "Alt+"),
1016        (ModifiersState::CONTROL, "Ctrl+"),
1017        (ModifiersState::SHIFT, "Shift+"),
1018    ] {
1019        if !mods.contains(modifier) {
1020            continue;
1021        }
1022
1023        mods_line.push_str(desc);
1024    }
1025    mods_line
1026}
pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl ModifiersState

pub const fn iter(&self) -> Iter<ModifiersState>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ModifiersState>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl ModifiersState

pub fn shift_key(&self) -> bool

Returns true if the shift key is pressed.

pub fn control_key(&self) -> bool

Returns true if the control key is pressed.

pub fn alt_key(&self) -> bool

Returns true if the alt key is pressed.

pub fn super_key(&self) -> bool

Returns true if the super key is pressed.