macOS / AppKit
Winit has an OS requirement of macOS 10.11 or higher (same as Rust itself), and is regularly tested on macOS 10.14.
A lot of functionality expects the application to be ready before you start doing anything; this includes creating windows, fetching monitors, drawing, and so on, see issues #2238, #2051 and #2087.
If you encounter problems, you should try doing your initialization inside
Event::Resumed.
Enums
- Activation
Policy - Corresponds to
NSApplicationActivationPolicy. - Colorspace
- Colorspace options for macOS windows.
- Option
AsAlt - Option as alt behavior.
Traits
- Active
Event Loop ExtMacOS - Event
Loop Builder ExtMacOS - Monitor
Handle ExtMacOS - Additional methods on
MonitorHandlethat are specific to MacOS. - Window
Attributes ExtMacOS - Additional methods on
WindowAttributesthat are specific to MacOS. - Window
ExtMacOS - Additional methods on
Windowthat are specific to MacOS.
Functions
- activate_
application - Bring the application owning
pidback to the front. - frontmost_
application_ pid - Additional methods on
ActiveEventLoopthat are specific to macOS. Process id of the frontmost application, orNonewhen that is this process, so a caller restoring focus never re-activates itself.