pub trait DeviceIdExtWindows {
// Required method
fn persistent_identifier(&self) -> Option<String>;
}Expand description
Additional methods on DeviceId that are specific to Windows.
Required Methods
Sourcefn persistent_identifier(&self) -> Option<String>
fn persistent_identifier(&self) -> Option<String>
Returns an identifier that persistently refers to this specific device.
Will return None if the device is no longer available.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".