pub trait WindowAttributesExtMacOS {
Show 14 methods
// Required methods
fn with_movable_by_window_background(
self,
movable_by_window_background: bool,
) -> Self;
fn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self;
fn with_title_hidden(self, title_hidden: bool) -> Self;
fn with_titlebar_hidden(self, titlebar_hidden: bool) -> Self;
fn with_titlebar_buttons_hidden(self, titlebar_buttons_hidden: bool) -> Self;
fn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self;
fn with_disallow_hidpi(self, disallow_hidpi: bool) -> Self;
fn with_has_shadow(self, has_shadow: bool) -> Self;
fn with_accepts_first_mouse(self, accepts_first_mouse: bool) -> Self;
fn with_tabbing_identifier(self, identifier: &str) -> Self;
fn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self;
fn with_unified_titlebar(self, unified_titlebar: bool) -> Self;
fn with_colorspace(self, colorspace: Colorspace) -> Self;
fn with_traffic_light_position(self, x: f64, y: f64) -> Self;
}Expand description
Additional methods on WindowAttributes that are specific to MacOS.
Note: Properties dealing with the titlebar will be overwritten by the
WindowAttributes::with_decorations method:
with_titlebar_transparentwith_title_hiddenwith_titlebar_hiddenwith_titlebar_buttons_hiddenwith_fullsize_content_view
Required Methods
Sourcefn with_movable_by_window_background(
self,
movable_by_window_background: bool,
) -> Self
fn with_movable_by_window_background( self, movable_by_window_background: bool, ) -> Self
Enables click-and-drag behavior for the entire window, not just the titlebar.
Sourcefn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self
fn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self
Makes the titlebar transparent and allows the content to appear behind it.
Hides the window title.
Hides the window titlebar.
Hides the window titlebar buttons.
Sourcefn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self
fn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self
Makes the window content appear behind the titlebar.
fn with_disallow_hidpi(self, disallow_hidpi: bool) -> Self
fn with_has_shadow(self, has_shadow: bool) -> Self
Sourcefn with_accepts_first_mouse(self, accepts_first_mouse: bool) -> Self
fn with_accepts_first_mouse(self, accepts_first_mouse: bool) -> Self
Window accepts click-through mouse events.
Sourcefn with_tabbing_identifier(self, identifier: &str) -> Self
fn with_tabbing_identifier(self, identifier: &str) -> Self
Defines the window tabbing identifier.
https://developer.apple.com/documentation/appkit/nswindow/1644704-tabbingidentifier
Sourcefn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self
fn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self
Set how the Option keys are interpreted.
See WindowExtMacOS::set_option_as_alt for details on what this means if set.
Sourcefn with_unified_titlebar(self, unified_titlebar: bool) -> Self
fn with_unified_titlebar(self, unified_titlebar: bool) -> Self
See WindowExtMacOS::set_unified_titlebar for details on what this means if set.
Sourcefn with_colorspace(self, colorspace: Colorspace) -> Self
fn with_colorspace(self, colorspace: Colorspace) -> Self
Sets the window’s colorspace for wide color gamut support.
Sourcefn with_traffic_light_position(self, x: f64, y: f64) -> Self
fn with_traffic_light_position(self, x: f64, y: f64) -> Self
Sets the position of the traffic light buttons (close, minimize, maximize). The position is specified as (x, y) coordinates in points from the top-left corner.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.